function draw_lines(m,n,r)

% This function draws the optimal tour for given m and n (size of the grid) 
% where the radius r is 0,1 or 2. The tour is plotted on a chessboard.
% This tours can be visualized for any m and n if r = 0, any m and n except
% m = 1 && n < 5 / m = 2 && n < 3 for r = 1 and any m and n except m = 3 &&
% n < 4 / m = 1 && n < 5 / m = 2 for r = 2.

% The idea of the program is to numerate the fields of A in the order they
% will be run through. (This is done by function numbering_matrix_...)
% A grid of size m x n is created by using meshgrid. The index of the current 
% number of A will be searched (started with 1, then 2 and so on) and at 
% this index the grid point will be plotted.

    help = false;
    if r == 0 || r == 1
        if n < m
           c = n;
           n = m;
           m = c;
           help = true;
        end
    end

    if r == 0
        A = numbering_matrix_zero(m,n);
    elseif r == 1
        if ( m == 1 && n <= 4 ) || ( m == 2 && n <= 2)
            error('There do not exist feasible tours for this dimensions');
        elseif (m == 1) || (m == 2) || (m == 4)
            A = numbering_matrix_one_specialcases(m,n);
        elseif mod(m,2)==1 && mod(n,2)==1
            A = numbering_matrix_one_oddodd(m,n);
        else
            A = numbering_matrix_one_(m,n);
        end
    elseif r == 2
        if m == 2
            error('No solution found');
        elseif m == 3 && n <= 3 
            error('There does not exist a feasible tour for this dimension!');
        elseif m >= 4
            A = numbering_matrix_sr2(m,n);
        end
    else
        error('r has to be 0, 1 or 2!')
    end
    
    if help
        A = rot90(A);
    end
    
    C = A(1:m/2,1:n);
    C = flipud(C);
    D = A(m/2+1:m,1:n);
    D = flipud(D);
    A = [D;C];
    
    [x,y] = meshgrid(1:n, 1:m);
    [row,col] = find(A == 1);
    a = x(row,col);
    b = y(row,col);

    axis([1 n 1 m]);
    grid on;
    hold on;
    
    plot(x,y,'Color',[.5 .5 .5],'Marker','*','LineStyle','none');
    
    for i = 1:n*m,
        pause(0.2);
        [row,col] = find(A == i);
        plot(x(row,col),y(row,col),'k*');
        plot([a x(row,col)],[b y(row,col)],'g');
        drawnow
        a = x(row,col);
        b = y(row,col);
    end
    
        pause(0.2);
        [row,col] = find(A == 1);
        plot(x(row,col),y(row,col),'k*');
        plot([a x(row,col)],[b y(row,col)],'g');
        drawnow
      